==> haskell-tasty-quickcheck-0.10-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-quickcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-quickcheck
version: 0.10
id: tasty-quickcheck-0.10-EAyCN7syYlRFDaodYKbrfK
key: tasty-quickcheck-0.10-EAyCN7syYlRFDaodYKbrfK
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
author: Roman Cheplyaka <roma@ro-che.info>
homepage: https://github.com/feuerbach/tasty
synopsis: QuickCheck support for the Tasty test framework.
description:
    QuickCheck support for the Tasty test framework.
category: Testing
abi: 42337256ea468637577255b8549202ff
exposed: True
exposed-modules:
    Test.Tasty.QuickCheck
import-dirs: /usr/lib/ghc-8.4.3/site-local/tasty-quickcheck-0.10
library-dirs: /usr/lib/ghc-8.4.3/site-local/tasty-quickcheck-0.10
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/tasty-quickcheck-0.10
hs-libraries: HStasty-quickcheck-0.10-EAyCN7syYlRFDaodYKbrfK
depends:
    base-4.11.1.0 tagged-0.8.5-8zhZJ4AR6AIK89q9NUJ4H
    tasty-1.1.0.1-IUVEcwSBXcEKkaWRvC6ppJ
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr
    optparse-applicative-0.14.2.0-2eDVpgsAe1xL6LOfCGKJrU
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             tagged-0.8.5-8zhZJ4AR6AIK89q9NUJ4H=8f78e013407135fc5016173a57c7eb1b
             tasty-1.1.0.1-IUVEcwSBXcEKkaWRvC6ppJ=68d4763af37bbcd176b315faa4b3bf6c
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=8df244958947206247b1dd733653312e
             QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=0b62adbb61d61aac8d449588192e831b
             optparse-applicative-0.14.2.0-2eDVpgsAe1xL6LOfCGKJrU=167699d54d61d2b1b6c082fc4a9ddc9b
haddock-interfaces: /usr/share/doc/haskell-tasty-quickcheck/html/tasty-quickcheck.haddock
haddock-html: /usr/share/doc/haskell-tasty-quickcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-quickcheck-0.10-13-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-quickcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-quickcheck
version: 0.10
id: tasty-quickcheck-0.10-Lpqx7SzUrov7mAceinwiH4
key: tasty-quickcheck-0.10-Lpqx7SzUrov7mAceinwiH4
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
author: Roman Cheplyaka <roma@ro-che.info>
homepage: https://github.com/feuerbach/tasty
synopsis: QuickCheck support for the Tasty test framework.
description:
    QuickCheck support for the Tasty test framework.
category: Testing
abi: 04e8394cfaf5c4bc34ecda366672d159
exposed: True
exposed-modules:
    Test.Tasty.QuickCheck
import-dirs: /usr/lib/ghc-8.4.3/site-local/tasty-quickcheck-0.10
library-dirs: /usr/lib/ghc-8.4.3/site-local/tasty-quickcheck-0.10
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/tasty-quickcheck-0.10
hs-libraries: HStasty-quickcheck-0.10-Lpqx7SzUrov7mAceinwiH4
depends:
    base-4.11.1.0 tagged-0.8.5-8zhZJ4AR6AIK89q9NUJ4H
    tasty-1.1.0.2-IyyNZADdDAPCV5drFrStAb
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr
    optparse-applicative-0.14.2.0-2eDVpgsAe1xL6LOfCGKJrU
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             tagged-0.8.5-8zhZJ4AR6AIK89q9NUJ4H=8f78e013407135fc5016173a57c7eb1b
             tasty-1.1.0.2-IyyNZADdDAPCV5drFrStAb=59f72506d54d37ce23f3ac95d2dd30ec
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=8df244958947206247b1dd733653312e
             QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=0b62adbb61d61aac8d449588192e831b
             optparse-applicative-0.14.2.0-2eDVpgsAe1xL6LOfCGKJrU=167699d54d61d2b1b6c082fc4a9ddc9b
haddock-interfaces: /usr/share/doc/haskell-tasty-quickcheck/html/tasty-quickcheck.haddock
haddock-html: /usr/share/doc/haskell-tasty-quickcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
